@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-gst.c,v 1.80 2004/04/09 13:38:47 hadess Exp $
+ * $Id: bacon-video-widget-gst.c,v 1.82 2004/05/30 12:21:10 hadess Exp $
  *
  */
 
@@ -980,7 +980,7 @@ bacon_video_widget_open (BaconVideoWidget * bvw, const gchar * mrl,
         gst_play_set_data_src (bvw->priv->play, datasrc);
       gst_play_set_location (bvw->priv->play, "/dev/video");
     }
-  else if (g_str_has_prefix (mrl, "cda://"))
+  else if (g_str_has_prefix (mrl, "cdda://"))
     {
       datasrc = gst_element_factory_make ("cdparanoia", "source");
       if (GST_IS_ELEMENT (datasrc))
@@ -1704,7 +1704,7 @@ bacon_video_widget_get_mrls (BaconVideoWidget * bvw, MediaType type)
       case MEDIA_CDDA:
         {
           mrls = g_malloc0 (sizeof (char *) * 2);
-          mrls[0] = "cda://";
+          mrls[0] = "cdda://";
           return mrls;
         }
       default:
@@ -1744,6 +1744,9 @@ bacon_video_widget_get_metadata_string (BaconVideoWidget * bvw,
     case BVW_INFO_AUDIO_CODEC:
       string = g_hash_table_lookup (bvw->priv->metadata_hash, "audio-codec");
       break;
+    case BVW_INFO_CDINDEX:
+      string = NULL;
+      break;
     default:
       g_assert_not_reached ();
     }
