@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget-xine.c,v 1.113 2004/04/16 22:51:30 hadess Exp $
+ * $Id: bacon-video-widget-xine.c,v 1.118 2004/05/30 12:21:10 hadess Exp $
  *
  * the xine engine in a widget - implementation
  */
@@ -124,8 +124,8 @@ struct BaconVideoWidgetPrivate {
 	/* Xine stuff */
 	xine_t *xine;
 	xine_stream_t *stream;
-	xine_vo_driver_t *vo_driver;
-	xine_ao_driver_t *ao_driver;
+	xine_video_port_t *vo_driver;
+	xine_audio_port_t *ao_driver;
 	xine_event_queue_t *ev_queue;
 	double display_ratio;
 	gboolean started;
@@ -175,23 +175,56 @@ struct BaconVideoWidgetPrivate {
 	int screenid;
 };
 
-static const char *mms_bandwidth_strs[]={"14.4 Kbps (Modem)",
-	"19.2 Kbps (Modem)", "28.8 Kbps (Modem)",
-	"33.6 Kbps (Modem)", "34.4 Kbps (Modem)",
-	"57.6 Kbps (Modem)", "115.2 Kbps (ISDN)",
-	"262.2 Kbps (Cable/DSL)", "393.2 Kbps (Cable/DSL)",
-	"524.3 Kbps (Cable/DSL)", "1.5 Mbps (T1)",
-	"10.5 Mbps (LAN)", NULL};
+static const char *mms_bandwidth_strs[] = {
+	"14.4 Kbps (Modem)",
+	"19.2 Kbps (Modem)",
+	"28.8 Kbps (Modem)",
+	"33.6 Kbps (Modem)",
+	"34.4 Kbps (Modem)",
+	"57.6 Kbps (Modem)",
+	"115.2 Kbps (ISDN)",
+	"262.2 Kbps (Cable/DSL)",
+	"393.2 Kbps (Cable/DSL)",
+	"524.3 Kbps (Cable/DSL)",
+	"1.5 Mbps (T1)",
+	"10.5 Mbps (LAN)",
+	NULL
+};
+
+static const char *audio_out_types_strs[] = {
+	"Mono",
+	"Stereo",
+	"Headphones",
+	"A52_Passthru",
+	"Surround21",
+	"Surround3",
+	"Surround4",
+	"Surround41",
+	"Surround5",
+	"Surround51",
+	"Surround6",
+	"Surround61",
+	"Surround71",
+	NULL
+};
+
+static const char *demux_strategies_str[] = {
+	"default",
+	"reverse",
+	"content",
+	"extension",
+	NULL
+};
 
 static void bacon_video_widget_class_init (BaconVideoWidgetClass *klass);
 static void bacon_video_widget_instance_init (BaconVideoWidget *bvw);
 
 static void setup_config (BaconVideoWidget *bvw);
 
-static void bacon_video_widget_set_property (GObject *object, guint property_id,
-		const GValue *value, GParamSpec *pspec);
-static void bacon_video_widget_get_property (GObject *object, guint property_id,
-		GValue *value, GParamSpec *pspec);
+static void bacon_video_widget_set_property (GObject *object,
+		guint property_id, const GValue *value, GParamSpec *pspec);
+static void bacon_video_widget_get_property (GObject *object,
+		guint property_id, GValue *value, GParamSpec *pspec);
 
 static void bacon_video_widget_realize (GtkWidget *widget);
 static void bacon_video_widget_unrealize (GtkWidget *widget);
@@ -208,9 +241,9 @@ static void bacon_video_widget_size_request (GtkWidget *widget,
 		GtkRequisition *requisition);
 static void bacon_video_widget_size_allocate (GtkWidget *widget,
 		GtkAllocation *allocation);
-static xine_vo_driver_t * load_video_out_driver (BaconVideoWidget *bvw,
+static xine_video_port_t * load_video_out_driver (BaconVideoWidget *bvw,
 		gboolean null_out);
-static xine_ao_driver_t * load_audio_out_driver (BaconVideoWidget *bvw,
+static xine_audio_port_t * load_audio_out_driver (BaconVideoWidget *bvw,
 		GError **error);
 static gboolean bacon_video_widget_tick_send (BaconVideoWidget *bvw);
 
@@ -220,7 +253,6 @@ static void xine_event (void *user_data, const xine_event_t *event);
 static gboolean bacon_video_widget_idle_signal (BaconVideoWidget *bvw);
 static void show_vfx_update (BaconVideoWidget *bvw, gboolean show_visuals);
 
-
 static int bvw_table_signals[LAST_SIGNAL] = { 0 };
 
 GType
@@ -539,13 +571,13 @@ frame_output_cb (void *bvw_gen,
 	*dest_pixel_aspect = bvw->priv->display_ratio;
 }
 
-static xine_vo_driver_t *
+static xine_video_port_t *
 load_video_out_driver (BaconVideoWidget *bvw, gboolean null_out)
 {
 	double res_h, res_v;
 	x11_visual_t vis;
 	const char *video_driver_id;
-	xine_vo_driver_t *vo_driver;
+	xine_video_port_t *vo_driver;
 
 	if (null_out != FALSE)
 	{
@@ -615,10 +647,10 @@ load_video_out_driver (BaconVideoWidget *bvw, gboolean null_out)
 	return vo_driver;
 }
 
-static xine_ao_driver_t *
+static xine_audio_port_t *
 load_audio_out_driver (BaconVideoWidget *bvw, GError **err)
 {
-	xine_ao_driver_t *ao_driver;
+	xine_audio_port_t *ao_driver;
 	const char *audio_driver_id;
 
 	if (bvw->priv->null_out != FALSE)
@@ -676,7 +708,7 @@ bvw_config_helper_string (xine_t *xine, const char *id, const char *val,
 }
 
 static void
-bvw_config_help_num (xine_t *xine, const char *id, int val,
+bvw_config_helper_num (xine_t *xine, const char *id, int val,
 		xine_cfg_entry_t *entry)
 {
 	memset (entry, 0, sizeof (entry));
@@ -724,8 +756,6 @@ setup_config (BaconVideoWidget *bvw)
 {
 	char *path;
 	xine_cfg_entry_t entry;
-	const char *demux_strategies[] = {"default", "reverse", "content",
-		"extension", NULL};
 
 	path = g_build_path (G_DIR_SEPARATOR_S,
 			g_get_home_dir (), CONFIG_FILE, NULL);
@@ -736,7 +766,7 @@ setup_config (BaconVideoWidget *bvw)
 	xine_config_register_enum (bvw->priv->xine,
 			"misc.demux_strategy",
 			0,
-			(char **) demux_strategies,
+			(char **) demux_strategies_str,
 			 "media format detection strategy",
 			 NULL, 10, NULL, NULL);
 
@@ -755,6 +785,17 @@ setup_config (BaconVideoWidget *bvw)
 	if (bvw->priv->gc == NULL)
 		return;
 
+	/* Disable CDDB, we'll use Musicbrainz instead */
+	bvw_config_helper_num (bvw->priv->xine,
+			"input.cdda_use_cddb", 1, &entry);
+	entry.num_value = 0;
+	xine_config_update_entry (bvw->priv->xine, &entry);
+
+	if (bvw->priv->gc == NULL) {
+		g_warning ("GConf not available, broken installation?");
+		return;
+	}
+
 	/* Setup the protocol handlers for our funky stuff */
 	setup_url_handlers (bvw, "pnm");
 	setup_url_handlers (bvw, "mms");
@@ -777,7 +818,7 @@ setup_config (BaconVideoWidget *bvw)
 			"/system/http_proxy/host", NULL);
 	xine_config_update_entry (bvw->priv->xine, &entry);
 
-	bvw_config_help_num (bvw->priv->xine,
+	bvw_config_helper_num (bvw->priv->xine,
 			 "input.http_proxy_port", 8080, &entry);
 	entry.num_value = gconf_client_get_int (bvw->priv->gc,
 			"/system/http_proxy/port", NULL);
@@ -821,12 +862,12 @@ setup_config_video (BaconVideoWidget *bvw)
 	xine_cfg_entry_t entry;
 
 	/* Default xv colourkey */
-	bvw_config_help_num (bvw->priv->xine, "video.xv_colorkey", 30, &entry);
+	bvw_config_helper_num (bvw->priv->xine, "video.xv_colorkey", 30, &entry);
 	entry.num_value = 30;
 	xine_config_update_entry (bvw->priv->xine, &entry);
 
 	/* Remove the ALSA HW mixing */
-	bvw_config_help_num (bvw->priv->xine, "audio.alsa_hw_mixer", 0, &entry);
+	bvw_config_helper_num (bvw->priv->xine, "audio.alsa_hw_mixer", 0, &entry);
 	entry.num_value = 0;
 	xine_config_update_entry (bvw->priv->xine, &entry);
 }
@@ -876,9 +917,8 @@ video_window_translate_point (BaconVideoWidget *bvw, int gui_x, int gui_y,
 	rect.w = 0;
 	rect.h = 0;
 
-	res = xine_gui_send_vo_data (bvw->priv->stream,
-				XINE_GUI_SEND_TRANSLATE_GUI_TO_VIDEO,
-				(void*)&rect);
+	res = xine_port_send_gui_data (bvw->priv->vo_driver,
+			XINE_GUI_SEND_TRANSLATE_GUI_TO_VIDEO, (void*)&rect);
 
 	if (res != -1)
 	{
@@ -1067,6 +1107,11 @@ bacon_video_widget_realize (GtkWidget *widget)
 
 	bvw = BACON_VIDEO_WIDGET (widget);
 
+	if (bvw->priv->mrl != NULL) {
+		bacon_video_widget_close (bvw);
+		g_warning ("bvw->priv->mrl != NULL on open");
+	}
+
 	/* set realized flag */
 	GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
 
@@ -1076,10 +1121,14 @@ bacon_video_widget_realize (GtkWidget *widget)
 	xine_dispose (bvw->priv->stream);
 	bvw->priv->stream = NULL;
 
-	if (bvw->priv->vo_driver != NULL)
-		xine_close_video_driver (bvw->priv->xine, bvw->priv->vo_driver);
-	if (bvw->priv->ao_driver != NULL)
-		xine_close_audio_driver (bvw->priv->xine, bvw->priv->ao_driver);
+	if (bvw->priv->vo_driver != NULL) {
+		xine_close_video_driver (bvw->priv->xine,
+				bvw->priv->vo_driver);
+	}
+	if (bvw->priv->ao_driver != NULL) {
+		xine_close_audio_driver (bvw->priv->xine,
+				bvw->priv->ao_driver);
+	}
 
 	/* Create the widget's window */
 	attr.x = widget->allocation.x;
@@ -1094,6 +1143,7 @@ bacon_video_widget_realize (GtkWidget *widget)
 	widget->window = gdk_window_new (gtk_widget_get_parent_window (widget),
 			&attr, GDK_WA_X | GDK_WA_Y);
 	gdk_window_show (widget->window);
+
 	/* Flush, so that the window is really shown */
 	gdk_flush ();
 	gdk_window_set_user_data (widget->window, bvw);
@@ -1353,19 +1403,38 @@ xine_event (void *user_data, const xine_event_t *event)
 static void
 xine_error (BaconVideoWidget *bvw, GError **error)
 {
-	signal_data *data;
+	signal_data *data, *save_data;
 	int err;
 
+	save_data = NULL;
+
 	/* Steal messages from the async queue, if there's an error,
 	 * to use as the error message rather than the crappy errors from
 	 * xine_open() */
-	data = g_async_queue_try_pop (bvw->priv->queue);
-	if (data != NULL) {
-		g_assert (data->signal == MESSAGE_ASYNC);
+	while ((data = g_async_queue_try_pop (bvw->priv->queue)) != NULL)
+	{
+		g_assert (data->signal == MESSAGE_ASYNC
+				|| data->signal == BUFFERING_ASYNC);
 
-		g_set_error (error, 0, 0, data->msg);
-		g_free (data->msg);
-		g_free (data);
+		if (data->signal != BUFFERING_ASYNC)
+		{
+			if (save_data != NULL)
+			{
+				g_free (save_data->msg);
+				g_free (save_data);
+			}
+			save_data = data;
+		} else {
+			g_free (data->msg);
+			g_free (data);
+		}
+	}
+
+	if (save_data != NULL)
+	{
+		g_set_error (error, 0, 0, save_data->msg);
+		g_free (save_data->msg);
+		g_free (save_data);
 
 		return;
 	}
@@ -1545,11 +1614,11 @@ bacon_video_widget_new (int width, int height, gboolean null_out, GError **err)
 
 	if (bvw->priv->null_out != FALSE)
 	{
-		bvw_config_help_num (bvw->priv->xine, "video.num_buffers",
+		bvw_config_helper_num (bvw->priv->xine, "video.num_buffers",
 				5, &entry);
 		entry.num_value = 5;
 	} else {
-		bvw_config_help_num (bvw->priv->xine, "video.num_buffers",
+		bvw_config_helper_num (bvw->priv->xine, "video.num_buffers",
 				500, &entry);
 		entry.num_value = 500;
 	}
@@ -1574,9 +1643,8 @@ bacon_video_widget_expose (GtkWidget *widget, GdkEventExpose *event)
 	expose = g_new0 (XExposeEvent, 1);
 	expose->count = event->count;
 
-	xine_gui_send_vo_data (bvw->priv->stream,
-			XINE_GUI_SEND_EXPOSE_EVENT,
-			expose);
+	xine_port_send_gui_data (bvw->priv->vo_driver,
+			XINE_GUI_SEND_EXPOSE_EVENT, expose);
 
 	g_free (expose);
 
@@ -1848,7 +1916,8 @@ bacon_video_widget_open (BaconVideoWidget *bvw, const char *mrl,
 
 	if (xine_get_stream_info (bvw->priv->stream,
 				XINE_STREAM_INFO_HAS_VIDEO) == FALSE
-		&& bvw->priv->ao_driver == NULL)
+		&& bvw->priv->ao_driver == NULL
+		&& bvw->priv->null_out != FALSE)
 	{
 		g_signal_emit (G_OBJECT (bvw),
 				bvw_table_signals[GOT_METADATA], 0, NULL);
@@ -2662,15 +2731,15 @@ bacon_video_widget_set_visuals_quality (BaconVideoWidget *bvw,
 		g_assert_not_reached ();
 	}
 
-	bvw_config_help_num (bvw->priv->xine, "post.goom_fps", fps, &entry);
+	bvw_config_helper_num (bvw->priv->xine, "post.goom_fps", fps, &entry);
 	entry.num_value = fps;
 	xine_config_update_entry (bvw->priv->xine, &entry);
 
-	bvw_config_help_num (bvw->priv->xine, "post.goom_width", w, &entry);
+	bvw_config_helper_num (bvw->priv->xine, "post.goom_width", w, &entry);
 	entry.num_value = w;
 	xine_config_update_entry (bvw->priv->xine, &entry);
 
-	bvw_config_help_num (bvw->priv->xine, "post.goom_height", h, &entry);
+	bvw_config_helper_num (bvw->priv->xine, "post.goom_height", h, &entry);
 	entry.num_value = h;
 	xine_config_update_entry (bvw->priv->xine, &entry);
 }
@@ -2686,7 +2755,8 @@ bacon_video_widget_get_auto_resize (BaconVideoWidget *bvw)
 }
 
 void
-bacon_video_widget_set_auto_resize (BaconVideoWidget *bvw, gboolean auto_resize)
+bacon_video_widget_set_auto_resize (BaconVideoWidget *bvw,
+		gboolean auto_resize)
 {
 	g_return_if_fail (bvw != NULL);
 	g_return_if_fail (BACON_IS_VIDEO_WIDGET (bvw));
@@ -2821,6 +2891,17 @@ G_CONST_RETURN char
 		(bvw->priv->xine, plugin_id, &num_mrls);
 }
 
+void
+bacon_video_widget_set_video_device (BaconVideoWidget *bvw, const char *path)
+{
+	xine_cfg_entry_t entry;
+
+	bvw_config_helper_string (bvw->priv->xine,
+			"input.v4l_video_device_path", path, &entry);
+	entry.str_value = g_strdup (path);
+	xine_config_update_entry (bvw->priv->xine, &entry);
+}
+
 void
 bacon_video_widget_set_aspect_ratio (BaconVideoWidget *bvw,
 		BaconVideoWidgetAspectRatio ratio)
@@ -2977,51 +3058,47 @@ bacon_video_widget_set_audio_out_type (BaconVideoWidget *bvw,
 		BaconVideoWidgetAudioOutType type)
 {
 	xine_cfg_entry_t entry;
-	int four_channel, five_channel, five_one_channel, passthru;
+	int value;
 
 	g_return_if_fail (bvw != NULL);
 	g_return_if_fail (BACON_IS_VIDEO_WIDGET (bvw));
 	g_return_if_fail (bvw->priv->xine != NULL);
 
-	four_channel = five_channel = five_one_channel = passthru = 0;
+	xine_config_register_enum (bvw->priv->xine,
+			"audio.speaker_arrangement",
+			1,
+			(char **) audio_out_types_strs,
+			"Speaker arrangement",
+			NULL, 0, NULL, NULL); 
 
 	gconf_client_set_int (bvw->priv->gc,
 			GCONF_PREFIX"/audio_output_type",
 			type, NULL);
+
 	switch (type) {
 	case BVW_AUDIO_SOUND_STEREO:
-		/* Nothing to do */
+		value = 1;
 		break;
 	case BVW_AUDIO_SOUND_4CHANNEL:
-		four_channel = 1;
+		value = 6;
 		break;
 	case BVW_AUDIO_SOUND_5CHANNEL:
-		five_channel = 1;
+		value = 8;
 		break;
 	case BVW_AUDIO_SOUND_51CHANNEL:
-		five_one_channel = 1;
+		value = 9;
 		break;
 	case BVW_AUDIO_SOUND_AC3PASSTHRU:
-		passthru = 1;
+		value = 3;
 		break;
 	default:
-		g_assert_not_reached ();
+		value = 2;
+		g_warning ("Unsupported audio type %d selected", type);
 	}
 
-	bvw_config_help_num (bvw->priv->xine, "audio.four_channel", four_channel, &entry);
-	entry.num_value = four_channel;
-	xine_config_update_entry (bvw->priv->xine, &entry);
-
-	bvw_config_help_num (bvw->priv->xine, "audio.five_channel", five_channel,  &entry);
-	entry.num_value = five_channel;
-	xine_config_update_entry (bvw->priv->xine, &entry);
-
-	bvw_config_help_num (bvw->priv->xine, "audio.five_lfe_channel", five_one_channel, &entry);
-	entry.num_value = five_one_channel;
-	xine_config_update_entry (bvw->priv->xine, &entry);
-
-	bvw_config_help_num (bvw->priv->xine, "audio.a52_pass_through", passthru, &entry);
-	entry.num_value = passthru;
+	xine_config_lookup_entry (bvw->priv->xine,
+			"audio.speaker_arrangement", &entry);
+	entry.num_value = value;
 	xine_config_update_entry (bvw->priv->xine, &entry);
 }
 
@@ -3061,6 +3138,10 @@ bacon_video_widget_get_metadata_string (BaconVideoWidget *bvw, BaconVideoWidgetM
 		string = xine_get_meta_info (bvw->priv->stream,
 				XINE_META_INFO_AUDIOCODEC);
 		break;
+	case BVW_INFO_CDINDEX:
+		string = xine_get_meta_info (bvw->priv->stream,
+				XINE_META_INFO_CDINDEX_DISCID);
+		break;
 	default:
 		g_assert_not_reached ();
 	}
