@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: bacon-video-widget.h,v 1.40 2004/03/31 16:23:32 hadess Exp $
+ * $Id: bacon-video-widget.h,v 1.43 2004/05/10 00:47:56 hadess Exp $
  *
  * the xine engine in a widget - header
  */
@@ -135,12 +135,17 @@ G_CONST_RETURN gchar **bacon_video_widget_get_mrls
 						 (BaconVideoWidget *bvw,
 						  MediaType type);
 
+/* Video devices */
+void bacon_video_widget_set_video_device	 (BaconVideoWidget *bvw,
+						  const char *path);
+
 /* Metadata */
 typedef enum {
 	BVW_INFO_TITLE,
 	BVW_INFO_ARTIST,
 	BVW_INFO_YEAR,
 	BVW_INFO_DURATION,
+	BVW_INFO_CDINDEX,
 	/* Video */
 	BVW_INFO_HAS_VIDEO,
 	BVW_INFO_DIMENSION_X,
@@ -185,11 +190,23 @@ typedef enum {
 	BVW_VIDEO_HUE
 } BaconVideoWidgetVideoProperty;
 
+typedef enum {
+	BVW_RATIO_AUTO,
+	BVW_RATIO_SQUARE,
+	BVW_RATIO_FOURBYTHREE,
+	BVW_RATIO_ANAMORPHIC,
+	BVW_RATIO_DVB
+} BaconVideoWidgetAspectRatio;
+
 void bacon_video_widget_set_deinterlacing        (BaconVideoWidget *bvw,
 						  gboolean deinterlace);
 gboolean bacon_video_widget_get_deinterlacing    (BaconVideoWidget *bvw);
 
-void bacon_video_widget_toggle_aspect_ratio      (BaconVideoWidget *bvw);
+void bacon_video_widget_set_aspect_ratio         (BaconVideoWidget *bvw,
+						  BaconVideoWidgetAspectRatio
+						  ratio);
+int bacon_video_widget_get_aspect_ratio          (BaconVideoWidget *bvw);
+
 void bacon_video_widget_set_scale_ratio          (BaconVideoWidget *bvw,
 						  gfloat ratio);
 
