@@ -27,15 +27,30 @@
 #include <gdk/gdkkeysyms.h>
 #include <glade/glade.h>
 #include <gconf/gconf-client.h>
-#include <libgnome/gnome-desktop-item.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
 #include <string.h>
-#include <libgnome/gnome-i18n.h>
 
 #include "totem-pl-parser.h"
 #include "debug.h"
 
+#ifdef HAVE_GTK_ONLY
+#ifdef ENABLE_NLS
+#include <libintl.h>
+#define _(String) dgettext(GETTEXT_PACKAGE,String)
+#ifdef gettext_noop
+#define N_(String) gettext_noop(String)
+#else
+#define N_(String) (String)
+#endif /* gettext_noop */
+#else
+#define _(String) (String)
+#define N_(String) (String)
+#endif /* ENABLE_NLS */
+#else
+#include <libgnome/gnome-i18n.h>
+#endif /* HAVE_GTK_ONLY */
+
 #define PL_LEN (gtk_tree_model_iter_n_children (playlist->_priv->model, NULL))
 
 static void ensure_shuffled (TotemPlaylist *playlist, gboolean shuffle);
@@ -72,6 +87,9 @@ struct TotemPlaylistPrivate
 	/* Repeat mode */
 	gboolean repeat;
 
+	/* Reorder Flag */
+	gboolean drag_started;
+
 	/* Shuffle mode */
 	gboolean shuffle;
 	int *shuffled;
@@ -477,6 +495,63 @@ treeview_button_pressed (GtkTreeView *treeview, GdkEventButton *event,
 	return TRUE;
 }
 
+static gboolean 
+button_press_cb (GtkWidget *treeview, GdkEventButton *event, gpointer data)
+{ 
+	
+	gtk_drag_dest_unset (treeview);
+	g_signal_handlers_block_by_func (treeview, (GFunc) drop_cb, data);
+	gtk_tree_view_set_reorderable (GTK_TREE_VIEW (treeview), TRUE);
+	
+	return FALSE;
+}
+
+static gboolean 
+button_release_cb (GtkWidget *treeview, GdkEventButton *event, gpointer data)
+{
+	TotemPlaylist *playlist = (TotemPlaylist *)data;
+
+	if (!playlist->_priv->drag_started)
+	{
+		gtk_tree_view_set_reorderable (GTK_TREE_VIEW (treeview),
+				FALSE);
+		gtk_drag_dest_set (treeview, GTK_DEST_DEFAULT_ALL,
+				target_table, G_N_ELEMENTS (target_table),
+				GDK_ACTION_COPY);
+
+		g_signal_handlers_unblock_by_func (treeview,
+				(GFunc) drop_cb, data);
+		
+	}
+
+	return FALSE;
+}
+
+static void 
+drag_begin_cb (GtkWidget *treeview, GdkDragContext *context, gpointer data)
+{
+	TotemPlaylist *playlist = (TotemPlaylist *)data;
+
+	playlist->_priv->drag_started= TRUE;
+
+	return;
+}
+
+static void 
+drag_end_cb (GtkWidget *treeview, GdkDragContext *context, gpointer data)
+{
+	TotemPlaylist *playlist = (TotemPlaylist *)data;
+
+	playlist->_priv->drag_started = FALSE;
+	gtk_tree_view_set_reorderable (GTK_TREE_VIEW (treeview), FALSE); 
+	gtk_drag_dest_set (treeview, GTK_DEST_DEFAULT_ALL, target_table,
+        		G_N_ELEMENTS (target_table), GDK_ACTION_COPY);
+
+	g_signal_handlers_unblock_by_func (treeview, (GFunc) drop_cb, data);
+
+	return;
+}
+
 static void
 selection_changed (GtkTreeSelection *treeselection, TotemPlaylist *playlist)
 {
@@ -538,7 +613,7 @@ totem_playlist_add_files (GtkWidget *widget, TotemPlaylist *playlist)
 	fs = gtk_file_chooser_dialog_new (_("Select files"),
 			GTK_WINDOW (playlist), GTK_FILE_CHOOSER_ACTION_OPEN,
 			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-			GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+			GTK_STOCK_ADD, GTK_RESPONSE_ACCEPT,
 			NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (fs), GTK_RESPONSE_ACCEPT);
 	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (fs), TRUE);
@@ -1025,6 +1100,14 @@ init_treeview (GtkWidget *treeview, TotemPlaylist *playlist)
 	/* Drag'n'Drop */
 	g_signal_connect (G_OBJECT (treeview), "drag_data_received",
 			G_CALLBACK (drop_cb), playlist);
+        g_signal_connect (G_OBJECT (treeview), "button_press_event",
+			G_CALLBACK (button_press_cb), playlist);
+        g_signal_connect (G_OBJECT (treeview), "button_release_event",
+			G_CALLBACK (button_release_cb), playlist);
+	g_signal_connect (G_OBJECT (treeview), "drag_begin",
+                        G_CALLBACK (drag_begin_cb), playlist);
+         g_signal_connect (G_OBJECT (treeview), "drag_end",
+                        G_CALLBACK (drag_end_cb), playlist);
 	gtk_drag_dest_set (treeview, GTK_DEST_DEFAULT_ALL,
 			target_table, 1, GDK_ACTION_COPY);
 
@@ -1358,6 +1441,7 @@ totem_playlist_new (const char *glade_filename, GdkPixbuf *playing_pix)
 		return NULL;
 	}
 
+	gtk_dialog_set_has_separator (GTK_DIALOG (playlist), FALSE);
 	gtk_window_set_title (GTK_WINDOW (playlist), _("Playlist"));
 	gtk_dialog_add_buttons (GTK_DIALOG (playlist),
 			GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
