@@ -31,7 +31,23 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkvseparator.h>
 #include <gtk/gtkwindow.h>
+
+#ifdef HAVE_GTK_ONLY
+#ifdef ENABLE_NLS
+#include <libintl.h>
+#define _(String) dgettext(GETTEXT_PACKAGE,String)
+#ifdef gettext_noop
+#define N_(String) gettext_noop(String)
+#else
+#define N_(String) (String)
+#endif /* gettext_noop */
+#else
+#define _(String) (String)
+#define N_(String) (String)
+#endif /* ENABLE_NLS */
+#else
 #include <libgnome/gnome-i18n.h>
+#endif /* HAVE_GTK_ONLY */
 
 #include "totem-statusbar.h"
 
