@@ -29,6 +29,7 @@
 
 #include "totem-stock-icons.h"
 #include "totem-private.h"
+#include "video-utils.h"
 
 static GHashTable *icons_table = NULL;
 
@@ -118,6 +119,7 @@ totem_set_default_icons (Totem *totem)
 	item = glade_xml_get_widget (totem->xml, "tcw_next_button_image");
 	gtk_image_set_from_pixbuf (GTK_IMAGE (item),
 			PIXBUF_FOR_ID("stock-media-next"));
+
 	/* Screenshot button */
 	item = glade_xml_get_widget (totem->xml,
 			"tmw_take_screenshot_menu_item_image");
@@ -230,5 +232,13 @@ totem_named_icons_init (Totem *totem, gboolean refresh)
 		g_hash_table_insert (icons_table, (gpointer) items[i].fn1,
 				(gpointer) pixbuf);
 	}
+
+	/* Switch direction of the Play icon if we're in Right-To-Left */
+	if (gtk_widget_get_direction (totem->win) == GTK_TEXT_DIR_RTL)
+	{
+		totem_pixbuf_mirror (PIXBUF_FOR_ID("stock-media-play"));
+		totem_pixbuf_mirror (PIXBUF_FOR_ID("stock-media-next"));
+		totem_pixbuf_mirror (PIXBUF_FOR_ID("stock-media-prev"));
+	}
 }
 
