@@ -238,3 +238,38 @@ gboolean totem_display_is_local (void)
 
 	return FALSE;
 }
+
+void
+totem_pixbuf_mirror (GdkPixbuf *pixbuf)
+{
+	int i, j, rowstride, offset, right;
+	guchar *pixels;
+	int width, height, size;
+	guint32 tmp;
+
+	pixels = gdk_pixbuf_get_pixels (pixbuf);
+	g_return_if_fail (pixels != NULL);
+
+	width = gdk_pixbuf_get_width (pixbuf);
+	height = gdk_pixbuf_get_height (pixbuf);
+	rowstride = gdk_pixbuf_get_rowstride (pixbuf);
+	size = height * width * sizeof (guint32);
+
+	for (i = 0; i < size; i += rowstride)
+	{
+		for (j = 0; j < rowstride; j += sizeof(guint32))
+		{
+			offset = i + j;
+			right = i + (((width - 1) * sizeof(guint32)) - j);
+
+			if (right <= offset)
+				break;
+
+			memcpy (&tmp, pixels + offset, sizeof(guint32));
+			memcpy (pixels + offset, pixels + right,
+					sizeof(guint32));
+			memcpy (pixels + right, &tmp, sizeof(guint32));
+		}
+	}
+}
+
